using LeedsBeerQuest.API.Data.Contexts;
using LeedsBeerQuest.API.Data.Models;
using LeedsBeerQuest.API.Data.Services.Interfaces;
using Microsoft.EntityFrameworkCore;

namespace LeedsBeerQuest.API.Data.Services;

public class VenueService : IVenueService
{
    private readonly LeedsBeerQuestDbContext _context;

    public VenueService(LeedsBeerQuestDbContext context)
    {
        _context = context;
    }

    public async Task<IEnumerable<Venue>> GetAllVenues()
    {
        return await _context.Venues
            .Include(v => v.Category)
            .Include(v => v.Tags)
            .ToListAsync();
    }

    public async Task<Venue?> GetVenue(int venueId)
    {
        return await _context.Venues
            .Include(v => v.Category)
            .Include(v => v.Tags)
            .SingleOrDefaultAsync(v => v.Id == venueId);
    }

    public async Task<IEnumerable<Venue>> GetFilteredVenues(string[]? tags = null, string[]? categories = null)
    {
        var venues = _context.Venues
            .Include(v => v.Category)
            .Include(v => v.Tags);


        IQueryable<Venue> filteredVenues = venues;

        if (categories is { Length: > 0 })
        {
            filteredVenues = venues.Where(v => categories.Contains(v.Category.Name));
        }

        return await filteredVenues.ToListAsync();
    }
}